Simulations
***********

.. currentmodule:: hyppo.sims

Independence Simulations
------------------------
.. autofunction:: linear
.. autofunction:: exponential
.. autofunction:: cubic
.. autofunction:: joint_normal
.. autofunction:: step
.. autofunction:: quadratic
.. autofunction:: w_shaped
.. autofunction:: spiral
.. autofunction:: uncorrelated_bernoulli
.. autofunction:: logarithmic
.. autofunction:: fourth_root
.. autofunction:: sin_four_pi
.. autofunction:: sin_sixteen_pi
.. autofunction:: square
.. autofunction:: two_parabolas
.. autofunction:: circle
.. autofunction:: ellipse
.. autofunction:: diamond
.. autofunction:: multiplicative_noise
.. autofunction:: multimodal_independence

*K*-Sample Simulations
----------------------
.. autofunction:: rot_2samp
.. autofunction:: trans_2samp
.. autofunction:: gaussian_3samp
